@@ -1,3 +1,11 @@
+
+
+"""HWRT (handwriting recognition toolkit) is a collection of tools which
+   can be used for handwriting recognition. It offers much documentation.
+
+   If any questions are not covered by the documentation or if difficulties
+   with using HWRT occur, please contact info@martin-thoma.de"""
+
 from pkg_resources import get_distribution, DistributionNotFound
 import os.path
 
